# Users

- [Dify](https://github.com/langgenius/dify): An open-source LLM app development platform.
- [wren-engine](https://github.com/Canner/wren-engine): The semantic engine for LLMs, bringing semantic context to AI agents.
- [FileCodeBox](https://github.com/vastsa/FileCodeBox): File Express Cabinet - Anonymous Passcode Sharing Text, Files, Like Taking Express Delivery for Files
